#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 git-lfs
version:              1.2.5
visibility:           public
id:                   git-lfs-1.2.5-8SiTuYp1GFs97pubMd5iFI
key:                  git-lfs-1.2.5-8SiTuYp1GFs97pubMd5iFI
license:              AGPL-3.0-only
copyright:            2019 Joey Hess
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess
stability:            Stable
synopsis:             git-lfs protocol
description:          An implementation of the git-lfs protocol.
category:             Network
abi:                  bea455ef866c77a5a682f7da43cb2af6
exposed:              True
exposed-modules:      Network.GitLFS
import-dirs:          /usr/lib/ghc-9.6.6/site-local/git-lfs-1.2.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/git-lfs-1.2.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/git-lfs-1.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-git-lfs
hs-libraries:         HSgit-lfs-1.2.5-8SiTuYp1GFs97pubMd5iFI
depends:
    aeson-2.2.2.0-6c1DCPq2cjw7mSOIGM724W base-4.18.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-4uVw9MDvZ5oAae1xp3bqUp
    containers-0.6.7 http-client-0.7.19-5ssHakQzOHODxkRAhbUNfr
    http-types-0.12.4-EOP8M0z2aoj67cPO54IyNv
    network-uri-2.6.4.2-Dqmf2XZhpKk16ZGQymmkCW text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-git-lfs/html/git-lfs.haddock
haddock-html:         /usr/share/doc/haskell-git-lfs/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

